This patch adds closing of the PMD after running the tests.

Signed-off-by: Adam Dybkowski <adamx.dybkow...@intel.com>
---
 app/test/test_cryptodev.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/app/test/test_cryptodev.c b/app/test/test_cryptodev.c
index f91debc16..7dcd255de 100644
--- a/app/test/test_cryptodev.c
+++ b/app/test/test_cryptodev.c
@@ -976,8 +976,9 @@ ut_teardown(void)
 
        rte_cryptodev_stats_get(ts_params->valid_devs[0], &stats);
 
        /* Stop the device */
        rte_cryptodev_stop(ts_params->valid_devs[0]);
+       rte_cryptodev_close(ts_params->valid_devs[0]);
 }
 
 static int
@@ -976,8 +976,9 @@ ut_teardown(void)
        rte_cryptodev_stats_get(ts_params->valid_devs[0], &stats);
 
-       /* Stop the device */
+       /* Stop and close the device */
        rte_cryptodev_stop(ts_params->valid_devs[0]);
-- 
2.25.1

Reply via email to